<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 29, 2013 1:08:16 PM
 * @version $Rev$
 */

/**
 * Job class
 * Used to ....
 */
class Entity_Cron_Candidate extends Entity_Cron {

    public function getUrl() {
        $candidatesUrl = Environment_Installation::get_candidates_feed();
        if (@$this->sourceData['settings']['feed']) {
            $candidatesUrl .= '?' . $this->sourceData['settings']['feed'];
        }
        return $candidatesUrl;
    }

    public function process($data) {
        Utils_Cache::cleanEnvironment();
        $items = $data->channel->item;

        $itemsTable = $this->getArrayOfItems($items);

        $listOfFragments = array();
        $customFields = $this->getCustomFieldsData($items);
        /**
         * for each item in the table,
         * create a writer,
         * write,
         * collect a fragment
         */
        $count = 0;
        foreach ($itemsTable as $item) {
            $candidate = new Entity_Writer_Candidate($item, $this->sourceData['settings'], $customFields[$count]);
            $id = $candidate->write();
            array_push($listOfFragments, $candidate->getFragment($id));
            $this->interfacer->entity_set_property($id, 'source', $this->sourceData['id']);
            $this->interfacer->entity_set_property($id, 'source_cron', $this->sourceData['id']);
            $count++;
        }

        /**
         * launch the collector for all the items from this source.
         * creates a page in wordpress
         */
        $page = $this->getPage();
        if (!$page) {
            $collector = new Entity_Writer_Collector($this->sourceData['name'], $this->sourceData['type'], $this->sourceData['id'], $listOfFragments, @$this->sourceData['settings']['introtext']);
            $collector->write();
        }


        return count($itemsTable);
    }

    /**
     * Formats the retrieved xml into a list of tables
     * 
     * 
     * @param SimpleXML $data
     * @return array
     */
    private function getArrayOfItems($data) {
        $items = array();

        $collectors = array(
            'guid', 'pubDate', 'name', 'reviewInfo', 'educations', 'firstName', 'initials',
            'functionGroup1', 'function1', 'functionGroup2', 'function2'
            , 'functionGroup3', 'function3'
        );
        
        if ($data) {
            foreach ($data as $item) {
                $newItem = array();

                $educations = array();
                foreach ($collectors as $collector) {
                    $name_collector = preg_replace('/\s+/u', ' | ', trim(strip_tags((string) $item->$collector)));
                    $name_collector = htmlentities($name_collector, null, 'utf-8');
                    $name_collector = str_replace('&nbsp;', '', $name_collector);
                    $name_collector = str_replace('&#160;', '', $name_collector);
                    if (strlen($name_collector) == 0)
                        continue;

                    if ($collector == 'educations') {
                        foreach ($item->$collector->education as $education) {
                            $education = array(
                                'education1' => (string) $education->education1,
                                'education2' => (string) $education->education2,
                                'education3' => (string) $education->education3,
                                'institute' => (string) $education->institute,
                                'start' => (string) $education->start,
                                'end' => (string) $education->end,
                                'diplomaTitle' => (string) $education->diplomaTitle,
                            );


                            array_push($educations, $education);
                        }
                        $newItem[$collector] = $educations;
                    }

                    if (isset($item->$collector) && strlen(trim((string) $item->$collector)) > 0) {
                        $newItem[$collector] = (string) $item->$collector;
                    }
                }

                if (!empty($newItem))
                    array_push($items, $newItem);
            }
        }
        return $items;
    }

    private function getCustomFieldsData($data) {
        $customFieldCollectors = array(
            'functionName', 'name', 'firstName', 'initials', 'lastName', 'guid', 'location',
            'availableFrom', 'availableTo', 'experienceInfo', 'workHistories', 'reviewInfo', 'skills', 'initials',
            'desiredRate', 'experience', 'age', 'gender', 'reviewInfo', 'desiredSalary'
        );
        $items = array();
        
        if ($data) {
            foreach ($data as $item) {
                $newItem = array();
                foreach ($customFieldCollectors as $collector) {

                    if ($collector == 'workHistories') {
                        $countWork = 0;
                        foreach ($item->$collector->work as $work) {
                            $work = (string) $work;
                            $newItem[$collector . '_' . $countWork] = $work;
                            $countWork++;
                        }
                    }

                    if ($collector == 'skills') {
                        $skills = array();
                        foreach ($item->$collector->skill as $skill) {
                            $skills[] = preg_replace('/\s+/u', ' ', trim((string) $skill));
                        }
                        sort($skills);
                        $newItem['skills'] = implode("\n", $skills);
                    }

                    if (isset($item->$collector) && strlen(trim((string) $item->$collector)) > 0) {
                        $newItem[$collector] = preg_replace('/\s+/u', ' ', trim((string) $item->$collector));
                    }
                }
                if (!empty($newItem))
                    array_push($items, $newItem);
            }
        }

        return $items;
    }

}
