<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 28, 2013 2:49:10 PM
 * @version $Rev$
 */


/**
 * Source class
 * Used to manipulate the sources table
 */
class Entity_Source {

	private   $id = false;
	private   $sourceTable = null;
	private   $interfacer = null;
	protected $type = false;

	/**
	 * 
	 * @param int $id id of the source row
	 */
	public function __construct($id = false)
	{
		$this->interfacer = WP_Interfacer::getInstance();
		$this->id = $id;
		
		$this->sourceTable = new WP_Table(Environment_Installation::TABLE_SOURCES);
		
		if($this->id)
		{
			$this->sourceTable->getByID($this->id);
		}
	}
	
	/**
	 * data must be in the form of array('column_name' => 'column_value')
	 * 
	 * @param array $data
	 */
	public function save($data)
	{
		$data = $this->prepare($data);
		if($this->id)
		{
			 $this->sourceTable->update($this->id, $data);
		}
		else
		{
			 $this->id = $this->sourceTable->insert($data);
		}
	}
	
	/**
	 * Returns the id of this row
	 * 
	 * @return int
	 */
	public function getID()
	{
		return $this->id;
	}
	
	/**
	 * Returns the data for the row with the current id
	 * 
	 * @return array
	 */
	public function getData()
	{
		return $this->sourceTable->getByID($this->id);
	}
	
	/**
	 * Returns the type of this source
	 * 
	 * @return string
	 */
	public function getType()
	{
		return $this->type;
	}
	
	/**
	 * deletes the source with the current id
	 */
	public function delete()
	{
		$this->sourceTable->delete($this->id);
	}

	/**
	 * Adds extra columns to the source
	 * 
	 * @param array $data
	 * @return array
	 */
	private function prepare($data)
	{
		if(!is_array($data)) return;
		
		$current_user_id = $this->interfacer->user_current_id();
		$current_user_name = $this->interfacer->user_current_name();
		$date = $this->interfacer->user_current_time();
		
		$data['author_id'] = $current_user_id;
		$data['author_name'] = $current_user_name;
		$data['date'] = $date;
		
		$name = $data['name'];
		unset($data['name']);
		
		$save_data = array(
			'type' => $this->getType(),
			'name' => $name,
			'settings' => serialize($data),
		);
		
		return $save_data;
	}
	
	
}