/**
 * Configure the layout and behaviour of the accordion tabs
 */
jQuery(document).ready( function($) {
    $( "#cx_diagnostics_accordion" ).accordion({
        collapsible: true,
        heightStyle: "content",
        activate: function(event, ui) {
            if(ui.newHeader[0]) {
                switch (ui.newHeader[0].id) { // id attribute of H3
                    case "tab_general":
                        cx_diagnostics.populateDataTableGeneral();
                        break;
                    case "tab_activepublications":
                        cx_diagnostics.populateDataTableActiveJobPublications();
                        break;
                    case "tab_mediumchannels":
                        cx_diagnostics.populateDataTableMediumChannels();
                        break;
                }
            }
        }
    });
});

/**
 *
 */
const cx_diagnostics = (function () {
    const $ = jQuery;
    let dataTableGeneral, dataTableActiveJobPublications, dataTableMediumChannels;

    function populateDataTableGeneral() {
        if ( dataTableGeneral ) {
            dataTableGeneral.ajax.reload();
            return;
        }


        // $('#datatable_general').DataTable().columns.adjust().responsive.recalc();


        dataTableGeneral = $('#datatable_general').DataTable({
            ajax: {
                url: ajaxurl + "?action=cxwordpress_diagnostics&section=general",
                cache: false,
            },
/*
            columnDefs: [
                { "width": "30%", "targets": 0},
                { "targets": [0, 1],
                   "className": "dt-head-left"
                }
            ],
*/
            columns: [
                {data: 'item'},
                {data: 'value'}
            ],
            autoWidth: false,
            sScrollX: "100%",
            order: [],
            ordering: false,
            searching: false,
            paging: false,
            info: false,
            pageLength: 100
        }); //.DataTable()

        $(window).resize(function () {
            $('#datatable_general').DataTable().columns.adjust();
        });
    }

    function populateDataTableActiveJobPublications() {
        if ( dataTableActiveJobPublications ) {
            dataTableActiveJobPublications.ajax.reload();
            return;
        }

        dataTableActiveJobPublications = $('#datatable_activepublications').DataTable({
            processing: true,
            serverSide: true,
            dom: '<"toolbaractivepublications">lfrptip', // l=length, f=filter, r=processing, p=paging, t=table, i=information
            paging: true,
            pageLength: 20,
            lengthMenu: [20, 50, 100, 250],
            ajax: {
                url: ajaxurl + "?action=cxwordpress_diagnostics&section=active-publications",
                cache: false,
                dataSrc: function (json) {
                    for ( let i=0, ien=json.data.length ; i<ien ; i++ ) {
                        var pubClientNameTxt = json.data[i]['isAnonymous'] ? "anonymous" : "public";
                        var pubSalaryTxt = json.data[i]['isSalaryPublic'] ? "public" : "hidden";
                        json.data[i]['publicationID'] = json.data[i]['publicationID'] + " (" + json.data[i]['mediumCode'] + ")";
                        json.data[i]['vacancyMeta'] = json.data[i]['vacancyID'] + " (" + json.data[i]['jobTitle'] + ")";
                        json.data[i]['timeSpan'] = json.data[i]['timeSpan'];
                        json.data[i]['agencyName'] = json.data[i]['agencyName'];
                        json.data[i]['sensitiveSettings'] = "Client name: " + pubClientNameTxt + ", Salary: " + pubSalaryTxt;
                    }
                    return json.data;
                }
            },
            columnDefs: [
                { "orderable": false, targets: [2,3,4,5] }, // targets are the colidxs which are non-orderable
            ],
            columns: [
                {data: 'publicationID'},
                {data: 'titleInformation'},
                {data: 'vacancyMeta'},
                {data: 'timeSpan'},
                {data: 'agencyName'},
                {data: 'sensitiveSettings'}
            ],
            language: {
                search: '<i style="margin-left: 20px;" class="fa fa-filter" aria-hidden="true"></i> ',
                searchPlaceholder: 'Search...'
            },
            autoWidth: false,
            sScrollX: "100%",
            scroller: {
                loadingIndicator: true
            },
            order: [],
            ordering: true,
            searching: true,
            info: true
        }); //.DataTable()

        $(window).resize(function () {
            $('#datatable_activepublications').DataTable().columns.adjust();
        });

        // document.querySelector('div.toolbaractivepublications').innerHTML = '<b>Custom tool bar! Text/images etc.</b>';
    }

    function populateDataTableMediumChannels() {
        if ( dataTableMediumChannels ) {
            dataTableMediumChannels.ajax.reload();
            return;
        }

        dataTableMediumChannels = $('#datatable_mediumchannels').DataTable({
            ajax: {
                url: ajaxurl + "?action=cxwordpress_diagnostics&section=medium-channels",
                cache: false,
            },
            "createdRow": function( row, data, dataIndex){
                $(row).addClass( data['rowcss'] );
            },
/*
            columnDefs: [
                { "targets": [0, 1, 2, 3],
                   "className": "dt-head-left"
                }
            ],
*/
            columns: [
                {data: 'code'},
                {data: 'name'},
                {data: 'ishtml'},
                {data: 'notes'}
            ],
            autoWidth: false,
            sScrollX: "100%",
            order: [],
            ordering: false,
            searching: false,
            paging: false,
            info: false,
            pageLength: 100
        }); //.DataTable()

        $(window).resize(function () {
            $('#datatable_mediumchannels').DataTable().columns.adjust();
        });
    }

    return { // public interface
        populateDataTableGeneral: function() {
            return populateDataTableGeneral();
        },
        populateDataTableActiveJobPublications: function() {
            return populateDataTableActiveJobPublications();
        },
        populateDataTableMediumChannels: function() {
            return populateDataTableMediumChannels();
        }
    };

})();


/**
 * Handles logo image selection/removal/refreshing in the Google For Jobs settings page
 */
jQuery(document).ready( function($) {
    // Ajax request to refresh the image preview
    function Refresh_Image(the_id){
        var data = {
            action: 'myprefix_get_image',
            id: the_id
        };

        jQuery.get(ajaxurl, data, function(response) {
            if(response.success === true) {
                jQuery('#myprefix-preview-image').replaceWith( response.data.image );
                jQuery('input#myprefix_logo_remove').removeClass( 'hidden' );
            }
        });
    }

    var id = jQuery('input#myprefix_image_id').val();
    if (parseInt(id)) {
        jQuery('input#myprefix_logo_remove').removeClass( 'hidden' );
    }

    jQuery('input#myprefix_logo_remove').click(function(e) {
        e.preventDefault();
        // jQuery('#myprefix-preview-image').remove();
        $tag = '<img id="myprefix-preview-image" src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==" alt="" />';
        jQuery('#myprefix-preview-image').replaceWith( $tag );
        jQuery('#myprefix_image_id').attr('value', '');
        jQuery('input#myprefix_logo_remove').addClass( 'hidden' );
    });

    jQuery('input#myprefix_media_manager').click(function(e) {
        e.preventDefault();
        var image_frame;
        if(image_frame){
            image_frame.open();
        }
        // Define image_frame as wp.media object
        image_frame = wp.media({
            title: 'Select Media',
            multiple : false,
            library : {
                type : 'image',
            }
        });

        image_frame.on('close',function() {
            // On close, get selections and save to the hidden input
            // plus other AJAX stuff to refresh the image preview
            var selection =  image_frame.state().get('selection');
            var gallery_ids = new Array();
            var my_index = 0;
            selection.each(function(attachment) {
                gallery_ids[my_index] = attachment['id'];
                my_index++;
            });
            var ids = gallery_ids.join(",");
            if (ids) {
                jQuery('input#myprefix_image_id').val(ids);
                Refresh_Image(ids);
            } else {
                jQuery('input#myprefix_logo_remove').trigger("click");
            }
        });

        image_frame.on('open',function() {
            // On open, get the id from the hidden input
            // and select the appropiate images in the media manager
            var selection =  image_frame.state().get('selection');
            var ids = jQuery('input#myprefix_image_id').val().split(',');
            ids.forEach(function(id) {
                var attachment = wp.media.attachment(id);
                attachment.fetch();
                selection.add( attachment ? [ attachment ] : [] );
            });

        });

        image_frame.open();
    });
});
